@@ -6,7 +6,7 @@ const char *clear_screen = "\x1b[H\x1b[2J";
 const char *cursor_address = "\x1b[%ld;%ldH";
 const char *cursor_normal = "\x1b[?25h"; /* DECTCEM (in)Visible cursor */
 const char *cursor_invisible = "\x1b[?25l"; /* DECTCEM (in)Visible cursor */
-const char *eat_newline_glitch = (void *)1;
+const int eat_newline_glitch = 1;
 const char *enter_ca_mode = "\x1b[?1049h"; /* smcup */
 const char *exit_ca_mode = "\x1b[?1049l"; /* rmcup */
 const char *save_cursor = "\x1b""7";
