@@ -178,7 +178,7 @@ static const int fieldmap[TagLast] = {
 	[RSSTagContentEncoded]     = FeedFieldContent,
 	[RSSTagGuid]               = -1,
 	[RSSTagGuidPermalinkFalse] = FeedFieldId,
-	[RSSTagGuidPermalinkTrue]  = FeedFieldId, /* special-case: both a link and an id */
+	[RSSTagGuidPermalinkTrue]  = FeedFieldId, /* special case: both a link and an id */
 	[RSSTagLink]               = FeedFieldLink,
 	[RSSTagEnclosure]          = FeedFieldEnclosure,
 	[RSSTagAuthor]             = FeedFieldAuthor,
@@ -432,7 +432,7 @@ string_print_timestamp(String *s)
 }
 
 /* Convert time fields. Returns a signed (at least) 64-bit UNIX timestamp.
- * Parameters should be passed as they are in a struct tm:
+ * Parameters should be passed as they are in a struct tm and in a valid range:
  * that is: year = year - 1900, month = month - 1. */
 static long long
 datetounix(long long year, int mon, int day, int hour, int min, int sec)
@@ -448,8 +448,8 @@ datetounix(long long year, int mon, int day, int hour, int min, int sec)
 	/* optimization: handle common range year 1902 up to and including 2038 */
 	if (year - 2ULL <= 136) {
 		/* amount of leap days relative to 1970: every 4 years */
-		leaps = (year - 68) >> 2;
-		if (!((year - 68) & 3)) {
+		leaps = (year / 4) - 17; /* 17 leap years offset for 1902 - 1970 */
+		if (!(year & 3)) {
 			leaps--;
 			is_leap = 1;
 		} else {
