@@ -122,7 +122,7 @@ main(int argc, char *argv[])
 	char *name;
 	int i;
 
-	if (pledge(argc == 1 ? "stdio" : "stdio rpath", NULL) == -1)
+	if (pledge(argc <= 1 ? "stdio" : "stdio rpath", NULL) == -1)
 		err(1, "pledge");
 
 	if ((now = time(NULL)) == (time_t)-1)
@@ -139,7 +139,7 @@ main(int argc, char *argv[])
 	       tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
 	       tm->tm_hour, tm->tm_min, tm->tm_sec);
 
-	if (argc == 1) {
+	if (argc <= 1) {
 		printfeed(stdin, "");
 		checkfileerror(stdin, "<stdin>", 'r');
 	} else {
