@@ -275,37 +275,6 @@ tparmnull(const char *str, long p1, long p2, long p3, long p4, long p5, long p6,
 	return tparm((char *)str, p1, p2, p3, p4, p5, p6, p7, p8, p9);
 }
 
-/* Counts column width of character string. */
-static size_t
-colw(const char *s)
-{
-	wchar_t wc;
-	size_t col = 0, i, slen;
-	int inc, rl, w;
-
-	slen = strlen(s);
-	for (i = 0; i < slen; i += inc) {
-		inc = 1; /* next byte */
-		if ((unsigned char)s[i] < 32) {
-			continue;
-		} else if ((unsigned char)s[i] >= 127) {
-			rl = mbtowc(&wc, &s[i], slen - i < 4 ? slen - i : 4);
-			inc = rl;
-			if (rl < 0) {
-				mbtowc(NULL, NULL, 0); /* reset state */
-				inc = 1; /* invalid, seek next byte */
-				w = 1; /* replacement char is one width */
-			} else if ((w = wcwidth(wc)) == -1) {
-				continue;
-			}
-			col += w;
-		} else {
-			col++;
-		}
-	}
-	return col;
-}
-
 /* Format `len` columns of characters. If string is shorter pad the rest
  * with characters `pad`. */
 static int
@@ -1796,8 +1765,6 @@ item_row_get(struct pane *p, off_t pos)
 
 		linetoitem(estrdup(line), item);
 		free(line);
-
-		itemrow->data = item;
 	}
 	return itemrow;
 }
@@ -2005,8 +1972,8 @@ main(int argc, char *argv[])
 	if (lazyload)
 		panes[PaneItems].row_get = item_row_get;
 
-	feeds = ecalloc(argc, sizeof(struct feed));
-	if (argc == 1) {
+	feeds = ecalloc(argc <= 1 ? 1 : argc, sizeof(struct feed));
+	if (argc <= 1) {
 		nfeeds = 1;
 		f = &feeds[0];
 		f->name = "stdin";
@@ -2033,7 +2000,7 @@ main(int argc, char *argv[])
 			die("dup2(%d, 0): /dev/tty -> stdin", fd);
 		close(fd);
 	}
-	if (argc == 1)
+	if (argc <= 1)
 		feeds[0].fp = NULL;
 
 	if ((devnullfd = open("/dev/null", O_WRONLY)) == -1)
