@@ -82,7 +82,7 @@ main(int argc, char *argv[])
 	if (pledge("stdio rpath wpath cpath", NULL) == -1)
 		err(1, "pledge");
 
-	if (!(feeds = calloc(argc, sizeof(struct feed))))
+	if (!(feeds = calloc(argc <= 1 ? 1 : argc, sizeof(struct feed))))
 		err(1, "calloc");
 
 	if ((comparetime = getcomparetime()) == (time_t)-1)
@@ -96,7 +96,7 @@ main(int argc, char *argv[])
 	if (showsidebar && !(fpmenu = fopen("menu.html", "wb")))
 		err(1, "fopen: menu.html");
 
-	if (pledge(argc == 1 ? "stdio" : "stdio rpath", NULL) == -1)
+	if (pledge(argc <= 1 ? "stdio" : "stdio rpath", NULL) == -1)
 		err(1, "pledge");
 
 	fputs("<!DOCTYPE HTML>\n"
@@ -108,7 +108,7 @@ main(int argc, char *argv[])
 	      "</head>\n"
 	      "<body class=\"frame\"><div id=\"items\">", fpitems);
 
-	if (argc == 1) {
+	if (argc <= 1) {
 		feeds[0].name = "";
 		printfeed(fpitems, stdin, &feeds[0]);
 		checkfileerror(stdin, "<stdin>", 'r');
