@@ -80,10 +80,10 @@ main(int argc, char *argv[])
 	FILE *fp;
 	int i;
 
-	if (pledge(argc == 1 ? "stdio" : "stdio rpath", NULL) == -1)
+	if (pledge(argc <= 1 ? "stdio" : "stdio rpath", NULL) == -1)
 		err(1, "pledge");
 
-	if (!(feeds = calloc(argc, sizeof(struct feed))))
+	if (!(feeds = calloc(argc <= 1 ? 1 : argc, sizeof(struct feed))))
 		err(1, "calloc");
 	if ((comparetime = getcomparetime()) == (time_t)-1)
 		errx(1, "getcomparetime");
@@ -103,7 +103,7 @@ main(int argc, char *argv[])
 	else
 		fputs("\t\t<div id=\"items\" class=\"nosidebar\">\n", stdout);
 
-	if (argc == 1) {
+	if (argc <= 1) {
 		feeds[0].name = "";
 		printfeed(stdin, &feeds[0]);
 		checkfileerror(stdin, "<stdin>", 'r');
