@@ -2,14 +2,17 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <unistd.h>
 
 #include "util.h"
 
 static char *line;
 static size_t linesize;
-static char host[256], *user, dtimebuf[32], mtimebuf[32];
-static int usecontent = 0; /* env variable: $SFEED_MBOX_CONTENT */
+static char dtimebuf[32], mtimebuf[32];
+
+/* env variables: $SFEED_MBOX_FROM and $SFEED_MBOX_TO */
+static char *from = NULL, *to = "<anonymous@localhost>";
+/* env variable: $SFEED_MBOX_CONTENT */
+static int usecontent = 0;
 
 static unsigned long long
 djb2(unsigned char *s, unsigned long long hash)
@@ -21,18 +24,44 @@ djb2(unsigned char *s, unsigned long long hash)
 	return hash;
 }
 
+/* Print the author field, do not allow quoted characters or text encoding. */
+static void
+printauthor(const char *s)
+{
+	for (; *s; s++) {
+		if (*s == '\\' || *s == '?' || *s == '=')
+			continue;
+		if (*s == '"')
+			putchar('\'');
+		else
+			putchar(*s);
+	}
+}
+
+/* Print the category field, replace the '|' separator by a comma (','). */
+static void
+printtags(const char *s)
+{
+	for (; *s; s++) {
+		if (*s == '|')
+			putchar(',');
+		else
+			putchar(*s);
+	}
+}
+
 /* Unescape / decode fields printed by string_print_encoded()
  * "\\" to "\", "\t", to TAB, "\n" to newline. Other escape sequences are
  * ignored: "\z" etc. Mangle "From " in mboxrd style (always prefix >). */
 static void
-printcontent(const char *s, FILE *fp)
+printcontent(const char *s)
 {
 escapefrom:
 	for (; *s == '>'; s++)
-		putc('>', fp);
+		putchar('>');
 	/* escape "From ", mboxrd-style. */
 	if (!strncmp(s, "From ", 5))
-		putc('>', fp);
+		putchar('>');
 
 	for (; *s; s++) {
 		switch (*s) {
@@ -42,15 +71,15 @@ escapefrom:
 			s++;
 			switch (*s) {
 			case 'n':
-				putc('\n', fp);
+				putchar('\n');
 				s++;
 				goto escapefrom;
-			case '\\': putc('\\', fp); break;
-			case 't':  putc('\t', fp); break;
+			case '\\': putchar('\\'); break;
+			case 't':  putchar('\t'); break;
 			}
 			break;
 		default:
-			putc(*s, fp); break;
+			putchar(*s); break;
 		}
 	}
 }
@@ -84,13 +113,22 @@ printfeed(FILE *fp, const char *feedname)
 			printf("Date: %s\n", dtimebuf); /* invalid/missing: use current time */
 		}
 
-		printf("From: %s <anonymous@>\n", fields[FieldAuthor][0] ? fields[FieldAuthor] : feedname);
-		printf("To: %s <%s@%s>\n", user, user, host);
+		if (from) {
+			printf("From: %s\n", from);
+		} else if (fields[FieldAuthor][0]) {
+			fputs("From: \"", stdout);
+			printauthor(fields[FieldAuthor]);
+			fputs("\" <anonymous@localhost>\n", stdout);
+		} else {
+			fputs("From: <anonymous@localhost>\n", stdout);
+		}
+
+		printf("To: %s\n", to);
 		printf("Subject: %s\n", fields[FieldTitle]);
-		printf("Message-ID: <%s%s%llu@%s>\n",
+		printf("Message-ID: <%s%s%llu@newsfeed.local>\n",
 		       fields[FieldUnixTimestamp],
 		       fields[FieldUnixTimestamp][0] ? "." : "",
-		       hash, feedname);
+		       hash);
 
 		ishtml = usecontent && !strcmp(fields[FieldContentType], "html");
 		if (ishtml)
@@ -98,7 +136,21 @@ printfeed(FILE *fp, const char *feedname)
 		else
 			fputs("Content-Type: text/plain; charset=\"utf-8\"\n", stdout);
 		fputs("Content-Transfer-Encoding: binary\n", stdout);
-		printf("X-Feedname: %s\n", feedname);
+		if (feedname[0])
+			printf("X-Feedname: %s\n", feedname);
+		if (fields[FieldAuthor][0])
+			printf("X-RSS-Author: %s\n", fields[FieldAuthor]);
+		if (fields[FieldEnclosure][0])
+			printf("X-RSS-Enclosure: %s\n", fields[FieldEnclosure]);
+		if (fields[FieldId][0])
+			printf("X-RSS-ID: %s\n", fields[FieldId]);
+		if (fields[FieldCategory][0]) {
+			fputs("X-RSS-TAGS: ", stdout);
+			printtags(fields[FieldCategory]);
+			fputs("\n", stdout);
+		}
+		if (fields[FieldLink][0])
+			printf("X-RSS-URL: %s\n", fields[FieldLink]);
 		fputs("\n", stdout);
 
 		if (ishtml) {
@@ -131,7 +183,7 @@ printfeed(FILE *fp, const char *feedname)
 				xmlencode(fields[FieldLink], stdout);
 				fputs("\"/>\n", stdout);
 			}
-			printcontent(fields[FieldContent], stdout);
+			printcontent(fields[FieldContent]);
 		}
 		fputs("\n\n", stdout);
 	}
@@ -146,15 +198,16 @@ main(int argc, char *argv[])
 	char *name, *tmp;
 	int i;
 
-	if (pledge(argc == 1 ? "stdio" : "stdio rpath", NULL) == -1)
+	if (pledge(argc <= 1 ? "stdio" : "stdio rpath", NULL) == -1)
 		err(1, "pledge");
 
 	if ((tmp = getenv("SFEED_MBOX_CONTENT")))
 		usecontent = !strcmp(tmp, "1");
-	if (!(user = getenv("USER")))
-		user = "you";
-	if (gethostname(host, sizeof(host)) == -1)
-		err(1, "gethostname");
+	if ((tmp = getenv("SFEED_MBOX_FROM")))
+		from = tmp;
+	if ((tmp = getenv("SFEED_MBOX_TO")))
+		to = tmp;
+
 	if ((now = time(NULL)) == (time_t)-1)
 		errx(1, "time");
 	if (!gmtime_r(&now, &tmnow))
@@ -164,7 +217,7 @@ main(int argc, char *argv[])
 	if (!strftime(dtimebuf, sizeof(dtimebuf), "%a, %d %b %Y %H:%M:%S +0000", &tmnow))
 		errx(1, "strftime: can't format current time");
 
-	if (argc == 1) {
+	if (argc <= 1) {
 		printfeed(stdin, "");
 		checkfileerror(stdin, "<stdin>", 'r');
 	} else {
