@@ -48,10 +48,10 @@ main(int argc, char *argv[])
 	char *name;
 	int i;
 
-	if (pledge(argc == 1 ? "stdio" : "stdio rpath", NULL) == -1)
+	if (pledge(argc <= 1 ? "stdio" : "stdio rpath", NULL) == -1)
 		err(1, "pledge");
 
-	if (argc == 1) {
+	if (argc <= 1) {
 		printfeed(stdin, "");
 		checkfileerror(stdin, "<stdin>", 'r');
 	} else {
