@@ -12,7 +12,7 @@ static void
 xmltagstart(XMLParser *p, const char *t, size_t tl)
 {
 	/* optimization: try to find a processing instruction only at the
-	   start of the data at the first few starting tags. */
+	 * start of the data at the first few starting tags. */
 	if (tags++ > 3)
 		exit(0);
 }
