@@ -406,3 +406,34 @@ printutf8pad(FILE *fp, const char *s, size_t len, int pad)
 	for (; col < len; ++col)
 		putc(pad, fp);
 }
+
+/* Counts column width of a character string. */
+size_t
+colw(const char *s)
+{
+	wchar_t wc;
+	size_t col = 0, i, slen;
+	int inc, rl, w;
+
+	slen = strlen(s);
+	for (i = 0; i < slen; i += inc) {
+		inc = 1; /* next byte */
+		if ((unsigned char)s[i] < 32) {
+			continue;
+		} else if ((unsigned char)s[i] >= 127) {
+			rl = mbtowc(&wc, &s[i], slen - i < 4 ? slen - i : 4);
+			inc = rl;
+			if (rl < 0) {
+				mbtowc(NULL, NULL, 0); /* reset state */
+				inc = 1; /* invalid, seek next byte */
+				w = 1; /* replacement char is one width */
+			} else if ((w = wcwidth(wc)) == -1) {
+				continue;
+			}
+			col += w;
+		} else {
+			col++;
+		}
+	}
+	return col;
+}
